==> haskell-row-types-1.0.1.2-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-3c5qY0wVEmUB09VNIPXF6z
key:                  row-types-1.0.1.2-3c5qY0wVEmUB09VNIPXF6z
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  5d7e87b35f97e291c46825a5d4ff3bc1
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-3c5qY0wVEmUB09VNIPXF6z
depends:
    base-4.17.2.1 constraints-0.14.1-A9mQ1p8Bv7F2nK81IgViPm
    deepseq-1.4.8.0 generic-lens-2.2.2.0-9ecT6onXxCh688rMIkwmwQ
    hashable-1.4.4.0-DGEtQXeqhKmCCbhJMtBsUM
    profunctors-5.6.3-3Hw57QUNqBl78NHz8f1hTZ text-2.0.2
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-row-types-1.0.1.2-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-C7QTrh9FHjb5UczwupSX63
key:                  row-types-1.0.1.2-C7QTrh9FHjb5UczwupSX63
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  22c7710f64afe41d59cb0f7f1b6f57f3
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-C7QTrh9FHjb5UczwupSX63
depends:
    base-4.17.2.1 constraints-0.14.1-1tsSwlSGMMdBVecBo79j8K
    deepseq-1.4.8.0 generic-lens-2.2.2.0-IrhDuz5GQBhHQCzARdJ5Qe
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb
    profunctors-5.6.3-DKBzX3YqV8IBJaFEhWlMk0 text-2.0.2
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
